/***********/
/* General */
/***********/

html, body { margin:0; padding: 0; height: 100%; font-family: "Trebuchet MS", Verdana, Arial, Helvetica; }

body { font-size: 10pt; background-color: #F1F1F1; min-width: 900px; }

.notification { color: #222222; font-style: italic; font-size:0.8em; }

#conteneur { height: auto !important; min-height: 100%; height: 100%; position: relative; }

.line-separator { height:1px; width:520px; background:#717171; border-bottom:1px solid #313030; margin-top:-25px; margin-left: 10px; margin-bottom: 45px; }

.descLegend { font-style: italic; }

.legendeTitle { font-variant: small-caps; font-weight: bold; font-size: 1.3em; line-height: 18pt; letter-spacing: 2px; }

#alignLeft { float: left; }

.italicPercent { font-style: italic; font-size: 0.7em; }

#contenu { padding-bottom: 50px; }

#contenu h4 { font-size: 1.6em; font-variant: small-caps; padding-left: 15px; letter-spacing: 2px; }

#contenu h3 { font-size: 1.2em; font-variant: small-caps; padding-left: 15px; letter-spacing: 2px; }

.displayGraph { border: 0px; }

div.uplink { margin-top: 30px; margin-left: 0; margin-right: 0; text-align: center; }

div.uplink a { color: #222222; text-decoration: none; font-variant: small-caps; font-weight: bold; }

div.uplink a:hover { color: #76add2; }

table.stata td a.domainLink { font-size: 0.9em; font-variant: normal; font-style: italic; }

table.graphs { margin-right: auto; margin-left: auto; }

table.stata th.headerBlack { color: #222222; font: bold 15px "Trebuchet MS", Verdana, Arial, Helvetica, sans-serif; font-variant: small-caps; }

table.stata { border-collapse: collapse; width: 90%; margin-left:auto; margin-right:auto; border: 0px; white-space:nowrap; }

table.stata th { background: #76add2; font: 12px "Trebuchet MS", Verdana, Arial, Helvetica, sans-serif; font-variant: small-caps; letter-spacing: 2px; padding-left: 20px; padding-right: 20px; padding-top: 3px; padding-bottom: 3px; border: 2px solid silver; color: #F1F1F1; }

table.stata td { text-align: center; padding-left: 20px; padding-right: 20px; padding-top: 5px; padding-bottom: 5px; border: 2px solid silver; font-style: italic; }

table.stata th.nobg { background: none; border-top: 0px; border-left: 0px; padding-left: 20px; padding-right: 20px; padding-top: 3px; padding-bottom: 3px; }

table.stata td a { font-variant: small-caps; text-decoration: none; color: #222222; font-weight: bold; font-style: normal; font-size: 14px; }

table.stata td a:hover { color: #76add2; }

.displayLegend { margin-left: 150px; }

.iconUpArrow { background-image: url("./images/up-arrow.png"); background-position: left bottom; background-repeat: no-repeat; padding-left: 25px; margin-bottom: 20px; }

/**************/
/*   Graphs   */
/**************/

#code_requests, #code_bytes, #network_hits, #network_bytes, #user_hits, #user_bytes, #domain_hits, #second_domain_hits, #domain_bytes, #second_domain_bytes {
     width : 550px;
     height: 300px;
     background:#F3F2ED;
     border:6px double white;
     padding:0 10px;
     margin:30px 10px 30px 10px;
     border-radius:10px;
     -moz-border-radius:10px;
     -webkit-border-radius:10px;
     box-shadow:3px 3px 6px 2px #A9A9A9;
     -moz-box-shadow:3px 3px 6px 2px #A9A9A9;
     -webkit-box-shadow:3px 3px 6px #A9A9A9;
}

/**************/
/*   Header   */
/**************/

.iconUpArrow { background-image: url("./images/up-arrow.png"); background-position: left bottom; background-repeat: no-repeat; padding-left: 25px; margin-bottom: 20px; }
#header { background: #222222; height: 130px; width: 100%; border-bottom: 3px solid #76add2; }
#header h1 { margin: 0; color: white; font-size: 3em; font-style: italic; font-variant: small-caps; letter-spacing: 2px; }
#header h1 img { float: left; margin-top: 5px; margin-right: 20px; padding-left: 20px; }
#header .sous-titre { color: #76add2; font-style: italic; padding-left: 180px; font-size:0.8em; font-weight: 600; }

/****************/
/*    Footer    */
/****************/

#footer { background: #222222; height: 30px; width: 100%; border-top: 3px solid #76add2; position: absolute; bottom: 0; }
#footer h4 { margin: 0; color: white; font-size: 0.8em; font-style: italic; text-align: right; padding-top: 8px; padding-right: 5px; }
#footer h4 a { color: silver; text-decoration: none; font-size: 1.1em; }
#footer h4 a:hover { color: #76add2; text-decoration: none; font-size: 1.1em; }

/***********************/
/*        Menu         */
/***********************/

ul { padding:0; margin:0; list-style-type:none; }
li { float:right; }
ul li a { display:block; width:125px; text-decoration:none; text-align:center; padding:5px; color: white; font-variant: small-caps; letter-spacing: 2px; }
ul li a:hover { color: #76add2; }
#menu { margin: 0 auto; padding: 0 auto; height: 28px; clear: both; background-color: #222222; border-bottom: 3px solid #76add2; }

.iconUser { background-image: url("./images/user.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }
.iconArrow { background-image: url("./images/back-arrow.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }
.iconDomain { background-image: url("./images/domain.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }
.iconNetwork { background-image: url("./images/network.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }
.iconUrl { background-image: url("./images/cursor.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }
.iconMime { background-image: url("./images/info.png"); background-position: left center; background-repeat: no-repeat; padding-left: 20px; }

/******************************/
/*         Calendar           */
/******************************/

#calendar { float: right; border: 0px; margin-top: 10px; margin-right: 10px; font-variant: small-caps; }
#calendar th { color: #76add2; background-color: #222222; border: 0px; font-style: italic; }
#calendar td { color: white; background-color: #222222; border: 0px; font-style: italic; }
#calendar table { width: 200px; position: right; background-color: #222222; color: white; text-align: center; border: 0px; }
#calendar table a { color: #76add2; }
#calendar table a:hover { color: silver; }

div.information {
        background:#F3F2ED;
        border:4px double white;
        padding:0 10px;
        margin:30px 0 30px 0;
        border-radius:10px;
        -moz-border-radius:10px;
        -webkit-border-radius:10px;
        box-shadow:3px 3px 6px 2px #A9A9A9;
        -moz-box-shadow:3px 3px 6px 2px #A9A9A9;
        -webkit-box-shadow:3px 3px 6px #A9A9A9;
        width: 1035px;
}

div.tooltipLink { position:relative; cursor:pointer; }
div.tooltipLink span.information { border-bottom:1px dotted gray; z-index:10; }
div.tooltipLink div.tooltip { display:none; background-color:#EBF0FC; border:1px solid #FFFFFF; -moz-border-radius:10px; padding:6px; width:250px; }
div.tooltipLink div.tooltip table { background-color:white; width:250px; }
div.tooltipLink div.tooltip table tr.row0 td { background-color: #FFFFFF; border: 1px solid #EEEEEE; }
div.tooltipLink div.tooltip table tr.row1 td { background-color: #EEEEEE; border: 1px solid #EEEEEE; }
div.tooltipLink div.tooltip th { font-size:10px; }
div.tooltipLink div.tooltip td { font-size:9px; font-weight:normal; padding:1px; }
div.tooltipLink:hover div.tooltip { display:block; z-index:20; position:absolute; top:1.5em; left:2em; }

